Namespace for discoverability (FrameGuardMatchers.meetsBudget(...)).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
jankRateBelow(
double maxRate) → Matcher - See hasJankRateBelow.
-
meetsBudget(
FrameBudget budget) → Matcher - Alias for meetsFrameBudget.
-
meetsFrameBudget(
FrameBudget budget) → Matcher - See top-level meetsFrameBudget.
-
p95Below(
Duration max) → Matcher - See hasP95Below.
-
p99Below(
Duration max) → Matcher - See hasP99Below.
Constants
- noSevereJank → const Matcher
- See hasNoSevereJank.