FrameGuardTest class

Test helpers for flutter_test and integration_test.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

measure(WidgetTester tester, {required String name, required Future<void> action(), FrameGuardSessionOptions? options, FrameBudget? budget, int warmupFrames = 5, Duration? warmup}) Future<FrameGuardReport>
Measures action under a FrameGuard session and returns the report.
measureSettled(WidgetTester tester, {required String name, required Future<void> action(), FrameBudget? budget, int settlePumps = 10}) Future<FrameGuardReport>
Runs action after warmup pumps, then measures.